@@ -30,11 +30,11 @@ class NotifyByTaskbar : public KNotificationPlugin
 {
     Q_OBJECT
 public:
-    NotifyByTaskbar(QObject *parent = 0);
+    NotifyByTaskbar(QObject *parent = nullptr);
     virtual ~NotifyByTaskbar();
 
-    virtual QString optionName() { return QStringLiteral("Taskbar"); }
-    virtual void notify(KNotification *notification, KNotifyConfig *config);
+    QString optionName() Q_DECL_OVERRIDE { return QStringLiteral("Taskbar"); }
+    void notify(KNotification *notification, KNotifyConfig *config) Q_DECL_OVERRIDE;
 };
 
 #endif
